help_out = b'This is a CLI tool for preprocessing data, training and evaluating PyTorch image classification models.\n\nUsage - tcv [-h|c|f] [--help|config|function|log]\n    -f  --file         :  Path to file to run code from. Ignored if -fn|--function is passed. -f will be given priority over function\n    -fn --function     :  Flag that determines the function to be done. One of train, test, preprocess. Ignored if -f|--file is passed\n    -c  --config       :  Path to config. Examples provided at - [Insert Link]\n    -v  --verbose      :  [Optional] Verbose Mode\n    -V  --version      :  Version of package\n        --log          :  [Optional] Log output to a file. Default at {pwd}/logs/{timestamp}.log\n        --log_dir      :  [Optional] Path to log directory. Ignored if --log is not passed.\n\n    -h  --help         :  Print help\n'

no_config_out = b'Config file not specified. Please pass the -c=|--config= argument\n\nAvailable options are -\nUsage - tcv [-h|c|f] [--help|config|function|log]\n    -f  --file         :  Path to file to run code from. Ignored if -fn|--function is passed. -f will be given priority over function\n    -f  --function     :  Flag that determines the function to be done. One of train, test, preprocess. Ignored if -f|--file is passed\n    -c  --config       :  Path to config. Examples provided at - [Insert Link]\n    -v  --verbose      :  [Optional] Verbose Mode\n    -V  --version      :  Version of package\n        --log          :  [Optional] Log output to a file. Default at {pwd}/logs/{timestamp}.log\n        --log_dir      :  [Optional] Path to log directory.\n\n    -h  --help         :  Print help\n'

no_function_out = b'Please pass either one of -f=*|--file=* OR -fn=[preprocess|test|train]|--function=[preprocess|test|train]\n\nAvailable options are -\nUsage - tcv [-h|c|f] [--help|config|function|log]\n    -f  --file         :  Path to file to run code from. Ignored if -fn|--function is passed. -f will be given priority over function\n    -f  --function     :  Flag that determines the function to be done. One of train, test, preprocess. Ignored if -f|--file is passed\n    -c  --config       :  Path to config. Examples provided at - [Insert Link]\n    -v  --verbose      :  [Optional] Verbose Mode\n    -V  --version      :  Version of package\n        --log          :  [Optional] Log output to a file. Default at {pwd}/logs/{timestamp}.log\n        --log_dir      :  [Optional] Path to log directory.\n\n    -h  --help         :  Print help\n'

wrong_option_out = b'Invalid option passed to script\n\nAvailable options are -\nUsage - tcv [-h|c|f] [--help|config|function|log]\n    -f  --file         :  Path to file to run code from. Ignored if -fn|--function is passed. -f will be given priority over function\n    -f  --function     :  Flag that determines the function to be done. One of train, test, preprocess. Ignored if -f|--file is passed\n    -c  --config       :  Path to config. Examples provided at - [Insert Link]\n    -v  --verbose      :  [Optional] Verbose Mode\n    -V  --version      :  Version of package\n        --log          :  [Optional] Log output to a file. Default at {pwd}/logs/{timestamp}.log\n        --log_dir      :  [Optional] Path to log directory.\n\n    -h  --help         :  Print help\n'

wrong_function_out = b'Please pass either one of -f=*|--file=* OR -fn=[preprocess|test|train]|--function=[preprocess|test|train]\n\nAvailable options are -\nUsage - tcv [-h|c|f] [--help|config|function|log]\n    -f  --file         :  Path to file to run code from. Ignored if -fn|--function is passed. -f will be given priority over function\n    -f  --function     :  Flag that determines the function to be done. One of train, test, preprocess. Ignored if -f|--file is passed\n    -c  --config       :  Path to config. Examples provided at - [Insert Link]\n    -v  --verbose      :  [Optional] Verbose Mode\n    -V  --version      :  Version of package\n        --log          :  [Optional] Log output to a file. Default at {pwd}/logs/{timestamp}.log\n        --log_dir      :  [Optional] Path to log directory.\n\n    -h  --help         :  Print help\n'
